@@ -5,9 +5,10 @@ from pathlib import Path
 import pandas
 import pytest
 
-EXAMPLE_DIR_WO_PARAMS = "mtp_wo_parameters"
-EXAMPLE_DIR_WITH_PARAMS = "mtp_with_parameters"
-EXAMPLE_DIR_WITH_RECORD = "record_time"
+EXAMPLE_DIR_CSV_WO_PARAMS = "csv_wo_parameters"
+EXAMPLE_DIR_CSV_WITH_PARAMS = "csv_with_parameters"
+EXAMPLE_DIR_XML_WO_PARAMS = "xml_wo_parameters"
+EXAMPLE_DIR_XML_WITH_PARAMS = "xml_with_parameters"
 
 
 @pytest.fixture(scope="session")
@@ -18,7 +19,7 @@ def example_dir(request):
 
 @pytest.fixture
 def example_file(example_dir):
-    data_dir = example_dir / EXAMPLE_DIR_WO_PARAMS
+    data_dir = example_dir / EXAMPLE_DIR_CSV_WO_PARAMS
     yield data_dir / "160218_SG2-013-001_Regen1_Cy3-100_1_A1_1.csv"
 
 
@@ -93,16 +94,16 @@ def normalization_data_frame():
 
 @pytest.fixture(scope="session")
 def parsed_data_frame_with_params(example_dir):
-    from sensospot_parser.parser import parse_folder
+    from sensospot_parser.csv_parser import parse_csv_folder
 
-    return parse_folder(example_dir / EXAMPLE_DIR_WITH_PARAMS)
+    return parse_csv_folder(example_dir / EXAMPLE_DIR_CSV_WITH_PARAMS)
 
 
 @pytest.fixture(scope="session")
 def parsed_data_frame_without_params(example_dir):
-    from sensospot_parser.parser import parse_folder
+    from sensospot_parser.csv_parser import parse_csv_folder
 
-    return parse_folder(example_dir / EXAMPLE_DIR_WO_PARAMS)
+    return parse_csv_folder(example_dir / EXAMPLE_DIR_CSV_WO_PARAMS)
 
 
 @pytest.fixture
